@@ -245,16 +245,16 @@ class ExperimentSection():
 
         See Also
         --------
-        ExperimentSection.all_subsections
+        experimentator.section.ExperimentSection.all_subsections
 
         Examples
         --------
-        Assuming the levels of the experiment saved in ``'example.exp'`` are
+        Assuming the levels of the experiment saved in ``'example.dat'`` are
         ``('participant', 'session', 'block', 'trial')``,
         this will return the third block of the second participant's first session:
 
         >>> from experimentator import Experiment
-        >>> exp = Experiment.load('example.exp')
+        >>> exp = Experiment.load('example.dat')
         >>> some_block = exp.subsection(participant=2, session=1, block=3)
 
         """
@@ -283,15 +283,15 @@ class ExperimentSection():
 
         See Also
         --------
-        ExperimentSection.subsection
+        experimentator.section.ExperimentSection.subsection
 
         Examples
         --------
-        Assuming the levels of the experiment saved in ``'example.exp'`` are
+        Assuming the levels of the experiment saved in ``'example.dat'`` are
         ``('participant', 'session', 'block', 'trial')``:
 
         >>> from experimentator import Experiment
-        >>> exp = Experiment.load('example.exp')
+        >>> exp = Experiment.load('example.dat')
 
         Get the  first session of each participant:
 
